Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

[Unreleased]
------------

Added
~~~~~
- Initial release of oduit
- ProcessManager for managing Odoo processes
- ConfigLoader for YAML configuration management
- OdooOperations for high-level Odoo operations
- ModuleManager for module operations
- DemoProcessManager for demo mode support
- Comprehensive test suite
- Documentation with Sphinx

Changed
~~~~~~~

Deprecated
~~~~~~~~~~

Removed
~~~~~~~

Fixed
~~~~~

Security
~~~~~~~~
